﻿using System;
using System.Collections.Generic;
using System.Text;

namespace BeeDevelopment.Infrared {
	public class InfraredCommandReceivedEventArgs : EventArgs  {
	
		#region Properties

		/// <summary>
		/// Gets the <see cref="SircsCommand"/> that was received.
		/// </summary>
		public InfraredCommand Command { get; private set; }

		/// <summary>
		/// Gets the number of times that the incoming command has been repeated when held.
		/// </summary>
		public int Repeat { get; private set; }

		#endregion

		#region Construction

		/// <summary>
		/// Creates a <see cref="SircsCommandReceivedEventArgs"/> instance.
		/// </summary>
		/// <param name="command">The <see cref="SircsCommand"/> that was recieved.</param>
		/// <param name="repeat">The number of times that the incoming command has been repeated when held.</param>
		public InfraredCommandReceivedEventArgs(InfraredCommand command, int repeat) {
			this.Command = command;
			this.Repeat = repeat;
		}

		#endregion

		#region Methods

		/// <summary>
		/// Converts the <see cref="SircsCommandReceivedEventArgs"/> into a string.
		/// </summary>
		/// <returns>A string representation of the <see cref="SircsCommandReceivedEventArgs"/>.</returns>
		public override string ToString() {
			return string.Format("{0}, Repeat={1}", this.Command, this.Repeat);
		}

		#endregion
	
	}
}
