﻿using System;

namespace BeeDevelopment.Infrared.Protocols {

	/// <summary>
	/// Represents a command sent by a NEC remote control.
	/// </summary>
	public class NecCommand : InfraredCommand {

		/// <summary>
		/// Gets the command ID of the button pressed.
		/// </summary>
		public int Command {
			get { return (int)this.GetRange(16, 8); }
		}

		/// <summary>
		/// Gets the address ID of the button pressed.
		/// </summary>
		public int Address {
			get { return (int)this.GetRange(0, this.IsExtended ? 16 : 8); }
		}

		public bool IsExtended {
			get { return this.IsValid && this.GetRange(0, 8) != ~this.GetRange(8, 8); }
		}

		/// <summary>
		/// Gets whether the command is valid or not.
		/// </summary>
		public bool IsValid {
			get {
				return this.GetRange(16, 8) == ~this.GetRange(24, 8);
			}
		}


		/// <summary>
		/// Converts the <see cref="NecCommand"/> into a descriptive string.
		/// </summary>
		/// <returns>A string describing the command.</returns>
		public override string ToString() {
			return string.Format("Address={0}, Command={1}, Extended={2}", this.Address, this.Command, this.IsExtended);
		}
	}
}