﻿using System;
using System.Collections.Generic;
using System.Text;

namespace BeeDevelopment.Infrared.Protocols {
	/// <summary>
	/// Represents a new Panasonic command.
	/// </summary>
	class NewPanasonicCommand : InfraredCommand {

		public int OemDevice1 {
			get { return (int)this.GetRange(8 * 0, 8); }
		}

		public int OemDevice2 {
			get { return (int)this.GetRange(8 * 1, 8); }
		}

		public int Device {
			get { return (int)this.GetRange(8 * 2, 8); }
		}

		public int SubDevice {
			get { return (int)this.GetRange(8 * 3, 8); }
		}

		public int Command {
			get { return (int)this.GetRange(8 * 4, 8); }
		}

		public int Checksum {
			get { return (int)this.GetRange(8 * 5, 8); }
		}

		public bool IsValid {
			get {
				return (byte)(this.Device ^ this.SubDevice ^ this.Command) == (byte)(this.Checksum);
			}
		}

		/// <summary>
		/// Converts the <see cref="OldPanasonicCommand"/> into a descriptive string.
		/// </summary>
		/// <returns>A string describing the command.</returns>
		public override string ToString() {
			return string.Format("OEM Device 1={0}, OEM Device 2={1}, Device={2}, Sub-Device={3}, Command={4}", this.OemDevice1, this.OemDevice2, this.Device, this.SubDevice, this.Command);
		}
	
	}
}
