﻿using System;

namespace BeeDevelopment.Infrared.Protocols {

	/// <summary>
	/// Represents a command sent by a RC5 remote control.
	/// </summary>
	public class RC5Command : InfraredCommand {

		/// <summary>
		/// Gets the command ID of the button pressed.
		/// </summary>
		public int Command {
			get { return (int)this.GetRange(0, 6); }
		}

		/// <summary>
		/// Gets the address ID of the button pressed.
		/// </summary>
		public int Address {
			get { return (int)this.GetRange(6, 5); }
		}

		/// <summary>
		/// Gets the repeat flag of the button pressed.
		/// </summary>
		public bool Repeat {
			get { return this[11]; }
		}

		/// <summary>
		/// Converts the <see cref="RC5Command"/> into a descriptive string.
		/// </summary>
		/// <returns>A string describing the command.</returns>
		public override string ToString() {
			return string.Format("Address={0}, Command={1}, Repeat={2}", this.Address, this.Command, this.Repeat);
		}

	}
}